@@ -24,7 +24,7 @@ class AddSignStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SignId: 签名ID。
         :type SignId: int
         """
@@ -48,7 +48,7 @@ class AddSmsSignRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SignName: 签名名称。
 注：不能重复申请已通过或待审核的签名。
         :type SignName: str
@@ -123,7 +123,7 @@ class AddSmsSignResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AddSignStatus: 添加签名响应
         :type AddSignStatus: :class:`tencentcloud.sms.v20210111.models.AddSignStatus`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -146,7 +146,7 @@ class AddSmsTemplateRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateName: 模板名称。
         :type TemplateName: str
         :param TemplateContent: 模板内容。
@@ -188,7 +188,7 @@ class AddSmsTemplateResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AddTemplateStatus: 添加短信模板响应包体
         :type AddTemplateStatus: :class:`tencentcloud.sms.v20210111.models.AddTemplateStatus`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -211,7 +211,7 @@ class AddTemplateStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateId: 模板ID。
         :type TemplateId: str
         """
@@ -235,7 +235,7 @@ class CallbackStatusStatistics(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CallbackCount: 短信回执量统计。
         :type CallbackCount: int
         :param RequestSuccessCount: 短信提交成功量统计。
@@ -291,7 +291,7 @@ class CallbackStatusStatisticsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BeginTime: 起始时间，格式为yyyymmddhh，精确到小时，例如2021050113，表示2021年5月1号13时。
         :type BeginTime: str
         :param EndTime: 结束时间，格式为yyyymmddhh，精确到小时，例如2021050118，表示2021年5月1号18时。
@@ -334,7 +334,7 @@ class CallbackStatusStatisticsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CallbackStatusStatistics: 回执数据统计响应包体。
         :type CallbackStatusStatistics: :class:`tencentcloud.sms.v20210111.models.CallbackStatusStatistics`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -357,7 +357,7 @@ class DeleteSignStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DeleteStatus: 删除状态信息。
         :type DeleteStatus: str
         :param DeleteTime: 删除时间，UNIX 时间戳（单位：秒）。
@@ -385,7 +385,7 @@ class DeleteSmsSignRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SignId: 待删除的签名 ID。
         :type SignId: int
         """
@@ -409,7 +409,7 @@ class DeleteSmsSignResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DeleteSignStatus: 删除签名响应
         :type DeleteSignStatus: :class:`tencentcloud.sms.v20210111.models.DeleteSignStatus`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -432,7 +432,7 @@ class DeleteSmsTemplateRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateId: 待删除的模板 ID。
         :type TemplateId: int
         """
@@ -456,7 +456,7 @@ class DeleteSmsTemplateResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DeleteTemplateStatus: 删除模板响应
         :type DeleteTemplateStatus: :class:`tencentcloud.sms.v20210111.models.DeleteTemplateStatus`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -479,7 +479,7 @@ class DeleteTemplateStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DeleteStatus: 删除状态信息。
         :type DeleteStatus: str
         :param DeleteTime: 删除时间，UNIX 时间戳（单位：秒）。
@@ -507,7 +507,7 @@ class DescribeSignListStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SignId: 签名ID。
         :type SignId: int
         :param International: 是否国际/港澳台短信，其中0表示国内短信，1表示国际/港澳台短信。
@@ -552,7 +552,7 @@ class DescribeSmsSignListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SignIdSet: 签名 ID 数组。
 注：默认数组最大长度100。
         :type SignIdSet: list of int non-negative
@@ -583,7 +583,7 @@ class DescribeSmsSignListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DescribeSignListStatusSet: 获取签名信息响应
         :type DescribeSignListStatusSet: list of DescribeSignListStatus
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -609,7 +609,7 @@ class DescribeSmsTemplateListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateIdSet: 模板 ID 数组。
 <dx-alert infotype="notice" title="注意">默认数组长度最大100</dx-alert>
         :type TemplateIdSet: list of int non-negative
@@ -640,7 +640,7 @@ class DescribeSmsTemplateListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DescribeTemplateStatusSet: 获取短信模板信息响应
         :type DescribeTemplateStatusSet: list of DescribeTemplateListStatus
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -666,7 +666,7 @@ class DescribeTemplateListStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateId: 模板ID。
         :type TemplateId: int
         :param International: 是否国际/港澳台短信，其中0表示国内短信，1表示国际/港澳台短信。
@@ -714,7 +714,7 @@ class ModifySignStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SignId: 签名ID。
         :type SignId: int
         """
@@ -738,7 +738,7 @@ class ModifySmsSignRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SignId: 待修改的签名 ID。
         :type SignId: int
         :param SignName: 签名名称。
@@ -817,7 +817,7 @@ class ModifySmsSignResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ModifySignStatus: 修改签名响应
         :type ModifySignStatus: :class:`tencentcloud.sms.v20210111.models.ModifySignStatus`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -840,7 +840,7 @@ class ModifySmsTemplateRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateId: 待修改模板的ID。
         :type TemplateId: int
         :param TemplateName: 新的模板名称。
@@ -886,7 +886,7 @@ class ModifySmsTemplateResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ModifyTemplateStatus: 修改模板参数响应
         :type ModifyTemplateStatus: :class:`tencentcloud.sms.v20210111.models.ModifyTemplateStatus`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -909,7 +909,7 @@ class ModifyTemplateStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateId: 模板ID。
         :type TemplateId: int
         """
@@ -933,7 +933,7 @@ class PullSmsReplyStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ExtendCode: 短信码号扩展号，默认未开通，如需开通请联系 [sms helper](https://cloud.tencent.com/document/product/382/3773#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81)。
         :type ExtendCode: str
         :param CountryCode: 国家（或地区）码。
@@ -981,7 +981,7 @@ class PullSmsReplyStatusByPhoneNumberRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BeginTime: 拉取起始时间，UNIX 时间戳（时间：秒）。
 注：最大可拉取当前时期前7天的数据。
         :type BeginTime: int
@@ -1027,7 +1027,7 @@ class PullSmsReplyStatusByPhoneNumberResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PullSmsReplyStatusSet: 回复状态响应集合。
         :type PullSmsReplyStatusSet: list of PullSmsReplyStatus
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1053,7 +1053,7 @@ class PullSmsReplyStatusRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Limit: 拉取最大条数，最多100条。
         :type Limit: int
         :param SmsSdkAppId: 短信 SdkAppId 在 [短信控制台](https://console.cloud.tencent.com/smsv2/app-manage) 添加应用后生成的实际 SdkAppId，例如1400006666。
@@ -1081,7 +1081,7 @@ class PullSmsReplyStatusResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PullSmsReplyStatusSet: 回复状态响应集合。
         :type PullSmsReplyStatusSet: list of PullSmsReplyStatus
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1107,7 +1107,7 @@ class PullSmsSendStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param UserReceiveTime: 用户实际接收到短信的时间，UNIX 时间戳（单位：秒）。
         :type UserReceiveTime: int
         :param CountryCode: 国家（或地区）码。
@@ -1155,7 +1155,7 @@ class PullSmsSendStatusByPhoneNumberRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BeginTime: 拉取起始时间，UNIX 时间戳（时间：秒）。
 注：最大可拉取当前时期前7天的数据。
         :type BeginTime: int
@@ -1201,7 +1201,7 @@ class PullSmsSendStatusByPhoneNumberResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PullSmsSendStatusSet: 下发状态响应集合。
         :type PullSmsSendStatusSet: list of PullSmsSendStatus
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1227,7 +1227,7 @@ class PullSmsSendStatusRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Limit: 拉取最大条数，最多100条。
         :type Limit: int
         :param SmsSdkAppId: 短信 SdkAppId 在 [短信控制台](https://console.cloud.tencent.com/smsv2/app-manage) 添加应用后生成的实际 SdkAppId，例如1400006666。
@@ -1255,7 +1255,7 @@ class PullSmsSendStatusResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PullSmsSendStatusSet: 下发状态响应集合。
         :type PullSmsSendStatusSet: list of PullSmsSendStatus
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1281,18 +1281,20 @@ class SendSmsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PhoneNumberSet: 下发手机号码，采用 E.164 标准，格式为+[国家或地区码][手机号]，单次请求最多支持200个手机号且要求全为境内手机号或全为境外手机号。
 例如：+8613711112222， 其中前面有一个+号 ，86为国家码，13711112222为手机号。
+注：发送国内短信格式还支持0086、86或无任何国家或地区码的11位手机号码，前缀默认为+86。
         :type PhoneNumberSet: list of str
         :param SmsSdkAppId: 短信 SdkAppId，在 [短信控制台](https://console.cloud.tencent.com/smsv2/app-manage)  添加应用后生成的实际 SdkAppId，示例如1400006666。
         :type SmsSdkAppId: str
         :param TemplateId: 模板 ID，必须填写已审核通过的模板 ID。模板 ID 可登录 [短信控制台](https://console.cloud.tencent.com/smsv2) 查看，若向境外手机号发送短信，仅支持使用国际/港澳台短信模板。
         :type TemplateId: str
-        :param SignName: 短信签名内容，使用 UTF-8 编码，必须填写已审核通过的签名，例如：腾讯云，签名信息可登录 [短信控制台](https://console.cloud.tencent.com/smsv2)  查看。
-注：国内短信为必填参数。
+        :param SignName: 短信签名内容，使用 UTF-8 编码，必须填写已审核通过的签名，例如：腾讯云，签名信息可登录 [短信控制台](https://console.cloud.tencent.com/smsv2) 查看。
+<dx-alert infotype="notice" title="注意">国内短信为必填参数。</dx-alert>
         :type SignName: str
         :param TemplateParamSet: 模板参数，若无模板参数，则设置为空。
+<dx-alert infotype="notice" title="注意">模板参数的个数需要与 TemplateId 对应模板的变量个数保持一致。</dx-alert>
         :type TemplateParamSet: list of str
         :param ExtendCode: 短信码号扩展号，默认未开通，如需开通请联系 [sms helper](https://cloud.tencent.com/document/product/382/3773#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81)。
         :type ExtendCode: str
@@ -1336,7 +1338,7 @@ class SendSmsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SendStatusSet: 短信发送状态。
         :type SendStatusSet: list of SendStatus
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1362,7 +1364,7 @@ class SendStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SerialNo: 发送流水号。
         :type SerialNo: str
         :param PhoneNumber: 手机号码，E.164标准，+[国家或地区码][手机号] ，示例如：+8613711112222， 其中前面有一个+号 ，86为国家码，13711112222为手机号。
@@ -1371,7 +1373,7 @@ class SendStatus(AbstractModel):
         :type Fee: int
         :param SessionContext: 用户 session 内容。
         :type SessionContext: str
-        :param Code: 短信请求错误码，具体含义请参考 [错误码](https://cloud.tencent.com/document/product/382/49316)。
+        :param Code: 短信请求错误码，具体含义请参考 [错误码](https://cloud.tencent.com/document/api/382/55981#6.-.E9.94.99.E8.AF.AF.E7.A0.81)，发送成功返回 "Ok"。
         :type Code: str
         :param Message: 短信请求错误码描述。
         :type Message: str
@@ -1410,7 +1412,7 @@ class SendStatusStatistics(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FeeCount: 短信计费条数统计，例如提交成功量为100条，其中有20条是长短信（长度为80字）被拆分成2条，则计费条数为： ```80 * 1 + 20 * 2 = 120``` 条。
         :type FeeCount: int
         :param RequestCount: 短信提交量统计。
@@ -1442,7 +1444,7 @@ class SendStatusStatisticsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BeginTime: 起始时间，格式为yyyymmddhh，精确到小时，例如2021050113，表示2021年5月1号13时。
         :type BeginTime: str
         :param EndTime: 结束时间，格式为yyyymmddhh，精确到小时，例如2021050118，表示2021年5月1号18时。
@@ -1485,7 +1487,7 @@ class SendStatusStatisticsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SendStatusStatistics: 发送数据统计响应包体。
         :type SendStatusStatistics: :class:`tencentcloud.sms.v20210111.models.SendStatusStatistics`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1508,7 +1510,7 @@ class SmsPackagesStatistics(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PackageCreateTime: 套餐包创建时间，UNIX 时间戳（单位：秒）。
         :type PackageCreateTime: int
         :param PackageEffectiveTime: 套餐包生效时间，UNIX 时间戳（单位：秒）。
@@ -1556,7 +1558,7 @@ class SmsPackagesStatisticsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SmsSdkAppId: 短信 SdkAppId 在 [短信控制台](https://console.cloud.tencent.com/smsv2/app-manage)  添加应用后生成的实际 SdkAppId，示例如1400006666。
         :type SmsSdkAppId: str
         :param Limit: 最大上限(需要拉取的套餐包个数)。
@@ -1598,7 +1600,7 @@ class SmsPackagesStatisticsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SmsPackagesStatisticsSet: 发送数据统计响应包体。
         :type SmsPackagesStatisticsSet: list of SmsPackagesStatistics
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
